<!DOCTYPE html>
<html lang="en">
    <head>
        <meta charset="utf-8">
        <meta http-equiv="X-UA-Compatible" content="IE=edge">
        <meta name="viewport" content="width=device-width, initial-scale=1">
        <meta name="generator" content="{{ config('app.name') }} v{{ config('app.version') }} (framework v{{ App::VERSION() }})">

        <title>@yield('title') | {{ UserConfig::get('app_name') }}</title>
        <base href="{{ url('/') }}">

        <meta name="csrf-token" content="{{ csrf_token() }}">

        {{-- Cannot use $theme_url here: if a theme uses the base layout, it would also have to provide all these dependencies! --}}
        {{-- As these files are shipped with core (not a theme) use the main app.version instead of the current theme's version --}}
        <link href="themes/base/bootstrap/css/bootstrap.min.css?v={{ urlencode(config('app.version')) }}" rel="stylesheet">
        <link href="themes/base/font-awesome/css/font-awesome.min.css?v={{ urlencode(config('app.version')) }}" rel="stylesheet">
        <link href="themes/base/css/app.css?v={{ urlencode(config('app.version')) }}" rel="stylesheet">

        @if (\App\Facade\Theme::hasStylesheet())
            <link href="{{ $theme_url }}/theme.css?v={{ urlencode($theme_version) }}" rel="stylesheet">
        @endif

        @stack('styles')
    </head>
    <body>
        @include('themes.base.partials.navbar')

        @yield('breadcrumb')

        <div class="container-fluid">
            @if (isset($error))
                <div class="container">
                    <div class="alert alert-danger">
                        <strong><i class="fa fa-exclamation-circle fa-fw"></i></strong> {{ $error }}
                    </div>
                </div>
            @endif

            @if (isset($warning))
                <div class="container">
                    <div class="alert alert-warning">
                        <strong><i class="fa fa-warning fa-fw"></i></strong> {{ $warning }}
                    </div>
                </div>
            @endif

            @if (isset($success))
                <div class="container">
                    <div class="alert alert-success">
                        <strong><i class="fa fa-info-circle fa-fw"></i></strong> {{ $success }}
                    </div>
                </div>
            @endif

            @if (isset($info))
                <div class="container">
                    <div class="alert alert-info">
                        <strong><i class="fa fa-info-circle fa-fw"></i></strong> {{ $info }}
                    </div>
                </div>
            @endif

            @yield('content')

            @if (isset($is_admin) && $is_admin)
                @include(\App\Facade\Theme::viewName('partials.copyright_admin'))
            @elseif (!\App\Facade\UserConfig::get('remove_copyright'))
                @include(\App\Facade\Theme::viewName('partials.copyright_gallery'))
            @endif
        </div>

        {{-- Cannot use $theme_url here: if a theme uses the base layout, it would also have to provide all these dependencies! --}}
        {{-- As these files are shipped with core (not a theme) use the main app.version instead of the current theme's version --}}
        <script src="themes/base/js/jquery.min.js?v={{ urlencode(config('app.version')) }}"></script>
        <script src="themes/base/bootstrap/js/bootstrap.min.js?v={{ urlencode(config('app.version')) }}"></script>
        <script src="themes/base/js/bootbox.min.js?v={{ urlencode(config('app.version')) }}"></script>
        <script src="themes/base/js/knockout.min.js?v={{ urlencode(config('app.version')) }}"></script>
        <script src="themes/base/js/app.js?v={{ urlencode(config('app.version')) }}"></script>
        <script type="text/javascript">
            function _bt_showLoadingModal() {
                bootbox.dialog({
                    closeButton: false,
                    message: '<center><img src="{{ asset('ripple.svg') }}"/></center>',
                    title: '@lang('global.please_wait')'
                });
            }

            $.ajaxSetup({
                headers: {
                    'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
                }
            });
        </script>
        @stack('scripts')
        {!! \App\Facade\UserConfig::get('analytics_code') !!}
    </body>
</html>
